@@ -3,6 +3,7 @@
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QDate>
+#include <QDir>
 
 #include <KI18n/KLocalizedString>
 
@@ -17,15 +18,18 @@
 
 #include "../buho_version.h"
 
-#include "buho.h"
-#include "models/books/booklet.h"
-#include "models/books/books.h"
+#include "owl.h"
 #include "models/notes/notes.h"
 
-//#include "doodle/doodlehanlder.h"
-
 #define BUHO_URI "org.maui.buho"
 
+static void setFolders()
+{
+    QDir notes_path(OWL::NotesPath.toLocalFile());
+    if (!notes_path.exists())
+        notes_path.mkpath(".");
+}
+
 int Q_DECL_EXPORT main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -41,14 +45,15 @@ int Q_DECL_EXPORT main(int argc, char *argv[])
     QApplication app(argc, argv);
 #endif
 
+    setFolders ();
+
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon(":/buho.png"));
 
     MauiApp::instance()->setIconName("qrc:/buho.svg");
-    MauiApp::instance()->setHandleAccounts(true);
 
     KLocalizedString::setApplicationDomain("buho");
-    KAboutData about(QStringLiteral("buho"), i18n("Buho"), BUHO_VERSION_STRING, i18n("Buho allows you to take quick notes and organize notebooks."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("buho"), i18n("Buho"), BUHO_VERSION_STRING, i18n("Create and organize your notes."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
     about.setProductName("maui/buho");
@@ -64,14 +69,9 @@ int Q_DECL_EXPORT main(int argc, char *argv[])
     about.setupCommandLine(&parser);
     about.processCommandLine(&parser);
 
-    Buho buho;
-
     QQmlApplicationEngine engine;
 
-    qmlRegisterAnonymousType<Booklet>(BUHO_URI, 1);
     qmlRegisterType<Notes>(BUHO_URI, 1, 0, "Notes");
-    qmlRegisterType<Books>(BUHO_URI, 1, 0, "Books");
-    //    qmlRegisterType<DoodleHanlder>(BUHO_URI, 1, 0, "Doodle");
 
     engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
     if (engine.rootObjects().isEmpty())
