@@ -3,8 +3,7 @@
 #include "notessyncer.h"
 
 #include <MauiKit/FileBrowsing/fm.h>
-#include <MauiKit/Core/mauiaccounts.h>
-#include <MauiKit/FileBrowsing/tagging.h>
+#include <MauiKit/Accounts/mauiaccounts.h>
 
 #include <algorithm>
 
@@ -19,19 +18,21 @@ Notes::Notes(QObject *parent)
     this->syncer->setProvider(new NextNote); // Syncer takes ownership of NextNote or the provider
 
     connect(syncer, &NotesSyncer::noteInserted, [&](FMH::MODEL note, STATE state) {
+
+      qDebug() << "Insertint new note" << note;
         if (state.type == STATE::TYPE::LOCAL)
             this->appendNote(note);
     });
 
     connect(syncer, &NotesSyncer::noteUpdated, [&](FMH::MODEL note, STATE state) {
         if (state.type == STATE::TYPE::LOCAL) {
-            const auto mappedIndex = this->mappedIndex(this->indexOf(FMH::MODEL_KEY::ID, note[FMH::MODEL_KEY::ID]));
-            if (mappedIndex >= 0) {
-                qDebug() << note[FMH::MODEL_KEY::MODIFIED];
+            const auto index = this->indexOf(FMH::MODEL_KEY::ID, note[FMH::MODEL_KEY::ID]);
+            if (index >= 0) {
+                qDebug() << note[FMH::MODEL_KEY::MODIFIED] << index;
                 note.insert(FMStatic::getFileInfoModel(note[FMH::MODEL_KEY::URL]));
                 qDebug() << note[FMH::MODEL_KEY::MODIFIED];
-                this->notes[mappedIndex] = note;
-                this->updateModel(mappedIndex, {});
+                this->notes[index] = note;
+                emit this->updateModel(index, {});
             }
         }
     });
@@ -50,6 +51,7 @@ void Notes::appendNote(FMH::MODEL note)
     emit this->preItemAppended();
     this->notes << note;
     emit this->postItemAppended();
+    emit this->countChanged();
 }
 
 const FMH::MODEL_LIST &Notes::items() const
@@ -71,9 +73,9 @@ bool Notes::update(const QVariantMap &data, const int &index)
     if (index < 0 || index >= this->notes.size())
         return false;
 
-    const auto index_ = this->mappedIndex(index);
+    auto note = this->notes[index];
+    qDebug() << "UDPATE MODEL ITEM AT "<< index << note[FMH::MODEL_KEY::TITLE];
 
-    auto note = this->notes[index_];
     note.insert(FMH::toModel(data));
     this->syncer->updateNote(note[FMH::MODEL_KEY::ID], note);
     return true;
@@ -84,11 +86,11 @@ bool Notes::remove(const int &index)
     if (index < 0 || index >= this->notes.size())
         return false;
 
-    const auto index_ = this->mappedIndex(index);
-
-    emit this->preItemRemoved(index_);
-    this->syncer->removeNote(this->notes.takeAt(index_)[FMH::MODEL_KEY::ID]);
+    emit this->preItemRemoved(index);
+    this->syncer->removeNote(this->notes.takeAt(index).value(FMH::MODEL_KEY::ID));
     emit this->postItemRemoved();
+    emit this->countChanged();
+
     return true;
 }
 
@@ -104,21 +106,18 @@ int Notes::indexOfName(const QString &query)
         });
 
         if (it != this->items().constEnd())
-            return this->mappedIndexFromSource(std::distance(this->items().constBegin(), it));
+            return std::distance(this->items().constBegin(), it);
         else
             return -1;
 }
 
-QVariantMap Notes::get(const int &index) const
-{
-    if (index >= this->notes.size() || index < 0)
-        return QVariantMap();
-    return FMH::toMap(this->notes.at(this->mappedIndex(index)));
-}
-
-
 void Notes::componentComplete()
 {
-    qDebug() << "Get the fucking notes";
+    setList();
+}
+
+
+void Notes::setList()
+{
     this->syncer->getNotes();
 }
